# Changelog

## 0.1.0 (2026-02-24)

- Initial release
- `Client` class with 19 API methods (configs, versions, fetch, labels, exports, health)
- `get_config()` drop-in function with TTL caching
- `configure()` for setting global defaults
